<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip_?lang_cible=ja
// ** ne pas modifier le fichier **

return [

	// A
	'access_interface_graphique' => 'グラフィカルインターフェースに戻る',
	'access_mode_texte' => 'シンプルなテキストインターフェースを表示する',
	'admin_debug' => 'デバッグ',
	'admin_modifier_article' => '記事を修正する',
	'admin_modifier_auteur' => '著者を修正する',
	'admin_modifier_breve' => 'ニュースを修正する',
	'admin_modifier_mot' => 'キーワードを修正する',
	'admin_modifier_rubrique' => 'セクションを修正する',
	'admin_recalculer' => 'ページの再読み込み',
	'afficher_calendrier' => 'カレンダーを表示する',
	'afficher_trad' => '翻訳を表示する',
	'alerte_maj_impossible' => '<b>警告</b> MySQLは、データベースを@version@にアップデート出来ませんでした。 
データベースのアクセス権に問題があると思われます。プロバイダにお問い合わせく
ださい。',
	'alerte_modif_info_concourante' => '<b>警告</b> この情報は他の所で修正されました。現在の情報は：',
	'analyse_xml' => 'XML解析',
	'annuler' => '取り消す',
	'antispam_champ_vide' => '空白のままに残してください。',
	'articles_recents' => '最新の記事',
	'avis_1_erreur_saisie' => 'エラーが１件あり、入力された情報を確認してください。',
	'avis_archive_incorrect' => 'この圧縮ファイルは、SPIP用のファイルではありません。',
	'avis_archive_invalide' => 'この圧縮ファイルは無効です。',
	'avis_attention' => '警戒！',
	'avis_champ_incorrect_type_objet' => 'タイプ@type@のオブジェクトに対して、フィールド名@name@が無効です。',
	'avis_colonne_inexistante' => 'カラム@col@がありません。',
	'avis_erreur' => 'エラー： 下記を見る',
	'avis_erreur_connexion' => '接続エラー',
	'avis_erreur_cookie' => 'クッキーの問題',
	'avis_erreur_fonction_contexte' => '開発のエラーです。この機能は前後関係で呼び出されるべきではありません。',
	'avis_erreur_mysql' => 'SQLエラー',
	'avis_erreur_sauvegarde' => 'バックアップエラー (@type@@id_objet@)！',
	'avis_erreur_visiteur' => '管理エリアへのアクセスエラー',
	'avis_nb_erreurs_saisie' => 'エラーが@nb@件あり、入力された情報を確認してください。',

	// B
	'barre_a_accent_grave' => 'アクセント記号つきの大文字Aを挿入してください。',
	'barre_aide' => 'ページレイアウトを充実させるために、「ショートカット」を使用してください。',
	'barre_e_accent_aigu' => '鋭いアクセントで大文字Eを挿入してください',
	'barre_eo' => 'OとEの合字の挿入(訳注:主にフランス語で使用)',
	'barre_eo_maj' => 'OとEの合字の大文字を挿入(訳注:主にフランス語で使用)',
	'barre_euro' => '「€」記号を入れてください。',
	'barre_gras' => '太字にする {{ボールド}}',
	'barre_guillemets' => '\\"２重引用符\\"の間の場所',
	'barre_guillemets_simples' => '’一重引用符’の間の場所',
	'barre_intertitre' => '変える {{{subheading}}}',
	'barre_italic' => '{イタリック} にする',
	'barre_lien' => 'ハイパーリンクの差込 [リンク先->http://...]',
	'barre_lien_input' => 'あなたのハイパーリンクの目標を入力してください (あなたはフォームのURLに
http://mysite.com、あるいは単純にこのサイトの記事番号を与えてもよいです)。',
	'barre_note' => '変える [[Footnote]]',
	'barre_paragraphe' => '段落を作成する',
	'barre_quote' => '<quote>メッセージへ引用符</quote>',
	'bouton_changer' => '修正する',
	'bouton_chercher' => '検索する',
	'bouton_choisir' => '選択する',
	'bouton_deplacer' => '移動する',
	'bouton_download' => 'ダウンロードする',
	'bouton_enregistrer' => '保存する',
	'bouton_radio_desactiver_messagerie_interne' => '内部のメッセージ交換を停止する',
	'bouton_radio_envoi_annonces' => '編集告知を送信する',
	'bouton_radio_non_envoi_annonces' => '編集告知を送信しない',
	'bouton_radio_non_envoi_liste_nouveautes' => '最新ニュースリストを送信しない',
	'bouton_recharger_page' => 'ページを再読み込む',
	'bouton_telecharger' => 'アップロードする',
	'bouton_upload' => 'アップロードする',
	'bouton_valider' => '確認する',

	// C
	'cal_apresmidi' => '午後',
	'cal_jour_entier' => '終日',
	'cal_matin' => '午前',
	'cal_par_jour' => '日めくりカレンダー',
	'cal_par_mois' => '月めくりカレンダー',
	'cal_par_semaine' => '週めくりカレンダー',
	'choix_couleur_interface' => '色',
	'choix_interface' => 'インターフェイスを選択する',
	'colonne' => 'コラム',
	'confirm_changer_statut' => '警戒！記事のステータスの変更をしてもらうように頼みました。続けますか。',
	'correcte' => '正解',

	// D
	'date_aujourdhui' => '今日',
	'date_avant_jc' => '紀元前',
	'date_dans' => '@delai@後',
	'date_de_mois_1' => '@nommois@@j@日',
	'date_de_mois_10' => '@nommois@@j@日',
	'date_de_mois_11' => '@nommois@@j@日',
	'date_de_mois_12' => '@nommois@@j@日',
	'date_de_mois_2' => '@nommois@@j@日',
	'date_de_mois_3' => '@nommois@@j@日',
	'date_de_mois_4' => '@nommois@@j@日',
	'date_de_mois_5' => '@nommois@@j@日',
	'date_de_mois_6' => '@nommois@@j@日',
	'date_de_mois_7' => '@nommois@@j@日',
	'date_de_mois_8' => '@nommois@@j@日',
	'date_de_mois_9' => '@nommois@@j@日',
	'date_demain' => '明日',
	'date_fmt_heures_minutes' => '@h@時@m@分',
	'date_fmt_heures_minutes_court' => '@h@時@m@分',
	'date_fmt_jour' => '@nomjour@ @jour@',
	'date_fmt_jour_heure' => '@jour@の@heure@',
	'date_fmt_jour_heure_debut_fin' => '@jour@に、@heure_debut@より@heure_fin@まで',
	'date_fmt_jour_heure_debut_fin_abbr' => '@dtstart@@jour@に、@heure_debut@@dtabbr@より@dtend@@heure_fin@@dtabbr@まで',
	'date_fmt_jour_mois' => '@nommois@@jour@日',
	'date_fmt_jour_mois_annee' => '@annee@年@nommois@@jour@日',
	'date_fmt_mois_annee' => '@annee@年@nommois@',
	'date_fmt_nomjour' => '@date@に@nomjour@日',
	'date_fmt_nomjour_date' => '@date@に@nomjour@日',
	'date_fmt_periode' => '@date_debut@より@date_fin@まで',
	'date_fmt_periode_abbr' => '@dtart@@date_debut@@dtabbr@より @dtend@@date_fin@@dtabbr@まで',
	'date_fmt_periode_from' => 'より',
	'date_fmt_periode_to' => 'まで',
	'date_fmt_saison_annee' => '@annee@年の@saison@',
	'date_heures' => '時間',
	'date_hier' => '昨日',
	'date_il_y_a' => '@delai@前',
	'date_jnum1' => '1',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => '日曜日',
	'date_jour_1_abbr' => '日',
	'date_jour_1_initiale' => '日',
	'date_jour_2' => '月曜日',
	'date_jour_2_abbr' => '月',
	'date_jour_2_initiale' => '月',
	'date_jour_3' => '火曜日',
	'date_jour_3_abbr' => '火',
	'date_jour_3_initiale' => '火',
	'date_jour_4' => '水曜日',
	'date_jour_4_abbr' => '水',
	'date_jour_4_initiale' => '水',
	'date_jour_5' => '木曜日',
	'date_jour_5_abbr' => '木',
	'date_jour_5_initiale' => '木',
	'date_jour_6' => '金曜日',
	'date_jour_6_abbr' => '金',
	'date_jour_6_initiale' => '金',
	'date_jour_7' => '土曜日',
	'date_jour_7_abbr' => '土',
	'date_jour_7_initiale' => '土',
	'date_jours' => '日',
	'date_minutes' => '分',
	'date_mois' => 'ヶ月',
	'date_mois_1' => '1月',
	'date_mois_10' => '10月',
	'date_mois_10_abbr' => '10月',
	'date_mois_11' => '11月',
	'date_mois_11_abbr' => '11月',
	'date_mois_12' => '12月',
	'date_mois_12_abbr' => '12月',
	'date_mois_1_abbr' => '1月',
	'date_mois_2' => '2月',
	'date_mois_2_abbr' => '2月',
	'date_mois_3' => '3月',
	'date_mois_3_abbr' => '3月',
	'date_mois_4' => '4月',
	'date_mois_4_abbr' => '4月',
	'date_mois_5' => '5月',
	'date_mois_5_abbr' => '5月',
	'date_mois_6' => '6月',
	'date_mois_6_abbr' => '6月',
	'date_mois_7' => '7月',
	'date_mois_7_abbr' => '7月',
	'date_mois_8' => '8月',
	'date_mois_8_abbr' => '8月',
	'date_mois_9' => '9月',
	'date_mois_9_abbr' => '9月',
	'date_saison_1' => '冬',
	'date_saison_2' => '春',
	'date_saison_3' => '夏',
	'date_saison_4' => '秋',
	'date_secondes' => '秒',
	'date_semaines' => '週',
	'date_un_mois' => '月',
	'date_une_heure' => '時間',
	'date_une_minute' => '分',
	'date_une_seconde' => '秒',
	'date_une_semaine' => '週間',
	'dirs_commencer' => '本インストールを始める前に…',
	'dirs_preliminaire' => 'まず： <b>アクセス権を設定する</b>',
	'dirs_probleme_droits' => 'アクセス権エラー',
	'dirs_repertoires_absents' => '<b>次のフォルダは見つかりませんでした： <ul>@bad_dirs@</ul></b><p>考えられる原因は小文字大文字の扱い方が間違っている。これらのフォルダの小文字大文字が上に表示されているものと一致しているかどうか確認してください。エラーを修正するために、FTPクライアントで、フォルダをリネームした上、出来ることになる。</p>',
	'dirs_repertoires_suivants' => '<b>次のフォルダに書き込む許可がありません： <ul>@bad_dirs@</ul></b><p>エラーを修正するために、FTPクライアントで、これらのフォルダにアクセス権を修正してください。手順はインストールガイドに記述してあります。</p>',
	'double_occurrence' => '二つの@balise@共起',

	// E
	'en_cours' => '処理中',
	'envoi_via_le_site' => 'サイトで送信する',
	'erreur' => 'エラー',
	'erreur_balise_non_fermee' => '最後のタグは閉じられていない。',
	'erreur_technique_ajaxform' => '予期のないエラーが起きて、フォームは送信されていません。やり直してください。',
	'erreur_technique_enregistrement_champs' => '技術的なエラーが起きて、フィルド@champs@が登録されません。',
	'erreur_technique_enregistrement_impossible' => '技術的なエラーが起きて、登録が不可能です。',
	'erreur_texte' => 'エラー',
	'etape' => '階',

	// F
	'fichier_introuvable' => 'ファイル@fichier@は見つからない。', # MODIF
	'form_auteur_confirmation' => 'メールアドレスを確認してください。',
	'form_auteur_email_modifie' => 'メールアドレスは変更されました。',
	'form_auteur_envoi_mail_confirmation' => '@email@に確認メールが送信されました。 このメールに記載されているウェブアドレスにアクセスしてから、登録されたメールアドレスを確認してください。',
	'form_auteur_mail_confirmation' => 'こんにちは。メールアドレスを変更してもらうように依頼しました。 新しいメールアドレスを確認するには、下のウェブアドレスに接続する必要があります。 （さもないと御要求は無視になります。）：@url@',
	'form_deja_inscrit' => '既に申し込み済みです。',
	'form_email_non_valide' => 'メールアドレスは有効ではありません。',
	'form_forum_access_refuse' => '当サイトにアクセスはもう禁止です。',
	'form_forum_bonjour' => '@nom@、こんにちは！',
	'form_forum_confirmer_email' => 'メールアドレスを確認するには、このリンク@url_confirm@をご覧ください。',
	'form_forum_email_deja_enregistre' => 'メールアドレスは登録済みで、いつものパスワードを使ってください。',
	'form_forum_identifiant_mail' => '新規ＩＤは、メールで送信されました。',
	'form_forum_identifiants' => '個人ＩＤ',
	'form_forum_indiquer_nom_email' => 'お名前とEメールアドレスを入力してください。 個人ＩＤをメールですぐに送信します。',
	'form_forum_login' => 'ログインＩＤ：',
	'form_forum_message_auto' => '(自動送信メッセージです)',
	'form_forum_pass' => 'パスワード：',
	'form_forum_probleme_mail' => 'メールエラー：ＩＤを送ることが出来ませんでした。',
	'form_forum_voici1' => 'サイトの生活に協力するために、この個人ＩＤを使ってください。"@nom_site_spip@" (@adresse_site@)：',
	'form_forum_voici2' => '当サイトに記事を提出するために、この個人ＩＤを使ってください。 "@nom_site_spip@" (@adresse_login@)：',
	'form_indiquer_email' => 'メールアドレスを入力して下さい。',
	'form_indiquer_nom' => 'お名前を入力して下さい。',
	'form_indiquer_nom_site' => 'あなたのサイトの名前を入力して下さい。',
	'form_pet_deja_enregistre' => 'このサイトは既に登録済みです。',
	'form_pet_signature_pasprise' => 'あなたの署名は無視されました。',
	'form_prop_confirmer_envoi' => '送信します。',
	'form_prop_description' => '説明/コメント',
	'form_prop_enregistre' => 'ご提案は登録されており、当サイトの管理者による検証した上で公開されます。', # MODIF
	'form_prop_envoyer' => 'メッセージを送る',
	'form_prop_indiquer_email' => '有効なメールアドレスを入力して下さい。',
	'form_prop_indiquer_nom_site' => 'サイトの名前を入力して下さい。',
	'form_prop_indiquer_sujet' => '題名を入力して下さい。',
	'form_prop_message_envoye' => 'メッセージは送られました。',
	'form_prop_non_enregistre' => 'ご提案は登録されませんでした。',
	'form_prop_sujet' => '題名',
	'form_prop_url_site' => 'サイトのURL',
	'format_date_incorrecte' => '日付か日付書式は正しくない。',
	'format_heure_incorrecte' => '時間か時間書式は正しくない。',
	'forum_non_inscrit' => '未登録かアドレスとパスワードが不合かどちらかです。',
	'forum_par_auteur' => '@auteur@で',
	'forum_titre_erreur' => 'エラー…',

	// I
	'ical_texte_rss_articles' => 'サイト内の記事の「バックエンド」が次のアドレスにあります：',
	'ical_texte_rss_articles2' => 'サイトの各セクションの記事のバックエンドファイルを取得することが出来ます：',
	'ical_texte_rss_breves' => 'さらに、サイト内のニュースを含んでいるファイルがあります。セクション番号を選択することによって、そのセクションだけのニュースを取得できます。',
	'icone_a_suivre' => 'つづき',
	'icone_admin_site' => 'サイトの管理',
	'icone_agenda' => 'カレンダー',
	'icone_aide_ligne' => 'ヘルプ',
	'icone_articles' => '記事',
	'icone_auteurs' => '著者',
	'icone_brouteur' => '素早いブラウジング',
	'icone_configuration_site' => '環境設定',
	'icone_configurer_site' => 'サイトの環境設定',
	'icone_creer_nouvel_auteur' => '新規著者を作成する',
	'icone_creer_rubrique' => '新規セクションを作成する',
	'icone_creer_sous_rubrique' => 'サブセクションを作成する',
	'icone_deconnecter' => 'ログアウト',
	'icone_discussions' => '話題',
	'icone_doc_rubrique' => 'セクション内のファイル',
	'icone_ecrire_article' => '新規記事を書く',
	'icone_edition_site' => '編集',
	'icone_gestion_langues' => '言語管理',
	'icone_informations_personnelles' => '個人情報',
	'icone_interface_complet' => '完全なインターフェース',
	'icone_interface_simple' => 'シンプルなインターフェース',
	'icone_maintenance_site' => 'サイトの整備',
	'icone_messagerie_personnelle' => '個人メッセージング',
	'icone_repartition_debut' => '初めからの配分を表示する',
	'icone_rubriques' => 'セクション',
	'icone_sauver_site' => 'サイトのバックアップ',
	'icone_site_entier' => 'サイトの全体',
	'icone_sites_references' => '参照されたサイト',
	'icone_statistiques' => 'サイトの統計',
	'icone_suivi_activite' => 'サイトへの協力',
	'icone_suivi_actualite' => 'サイトの進化',
	'icone_suivi_pettions' => '請願書の管理',
	'icone_suivi_revisions' => '記事修正の進化',
	'icone_supprimer_document' => 'このドキュメントを削除',
	'icone_supprimer_image' => 'この画像を削除する',
	'icone_tous_articles' => '私のすべての記事',
	'icone_tous_auteur' => 'すべての著者',
	'icone_tous_visiteur' => 'すべての訪問者',
	'icone_visiter_site' => '公開サイトを訪れる',
	'icone_voir_en_ligne' => 'オンラインで見る',
	'img_indisponible' => 'イメージは見つからない',
	'impossible' => '不可能',
	'info_a_suivre' => 'つづき',
	'info_acces_interdit' => 'アクセス禁止',
	'info_acces_refuse' => 'アクセスが拒否されました。',
	'info_action' => 'アクション：@action@',
	'info_administrer_rubriques' => 'このセクションとサブセクションを管理することができます。',
	'info_adresse_non_indiquee' => 'テストをするためのアドレスを指定しませんでした！',
	'info_aide' => 'ヘルプ：',
	'info_ajouter_mot' => 'このキーワードを追加する',
	'info_annonce' => '告知',
	'info_annonces_generales' => '一般告知：',
	'info_article_propose' => '提出済みの記事',
	'info_article_publie' => '公開された記事',
	'info_article_redaction' => '編集中の記事',
	'info_article_refuse' => '拒否された記事',
	'info_article_supprime' => '削除された記事',
	'info_articles' => '記事',
	'info_articles_a_valider' => '確認すべきの記事',
	'info_articles_nb' => '記事@nb@件',
	'info_articles_proposes' => '提出済みの記事',
	'info_articles_un' => '記事1件',
	'info_auteurs_nombre' => '著者：',
	'info_authentification_ftp' => 'FTPによる認証',
	'info_breves_2' => 'ニュース',
	'info_breves_nb' => 'ニュース@nb@件',
	'info_breves_un' => 'ニュース 1 件',
	'info_connexion_refusee' => '接続が拒否されました。',
	'info_contact_developpeur' => '開発者と連絡して下さい。', # MODIF
	'info_contenance' => '当サイトの内容：',
	'info_contribution' => '掲示板の投稿',
	'info_copyright' => '@spip@は、@lien_gpl@で配布されるフリーソフトです。',
	'info_copyright_doc' => '詳細情報は<a href="@spipnet@">@spipnet_affiche@</a>をご覧ください。',
	'info_copyright_gpl' => 'GPLライセンスのもとで',
	'info_cours_edition' => '編集中の記事', # MODIF
	'info_creer_repertoire' => 'ファイルかフォルダかかを作成してください：',
	'info_creer_repertoire_2' => 'サブフォルダー<b>@repertoire@</b>内、そして',
	'info_creer_vignette' => 'サムネイルの自動制作',
	'info_creerdansrubrique_non_autorise' => 'このセクションでコンテンツを作成するために、アクセス権が足りません。',
	'info_deplier' => '表示する',
	'info_descriptif_nombre' => '記述：',
	'info_description' => '記述：',
	'info_description_2' => '記述:',
	'info_dimension' => 'サイズ：',
	'info_documents_nb' => 'ファイル@nb@件',
	'info_documents_un' => 'ファイル 1 件',
	'info_ecire_message_prive' => 'プライベートメッセージを書く',
	'info_email_invalide' => 'メールアドレスは無効です。',
	'info_en_cours_validation' => '確認すべきの私の記事',
	'info_en_ligne' => 'オンライン中：',
	'info_envoyer_message_prive' => 'この著者にプライベートメッセージを送る',
	'info_erreur_requete' => 'クエリのエラー：',
	'info_erreur_squelette2' => 'テンプレート<b>@fichier@</b> が見つからない',
	'info_erreur_systeme' => 'システムエラー（エラー番号：@errsys@）',
	'info_erreur_systeme2' => 'ハードドライブがいっぱいになったか、データベースが破損している可能性があります。<br/>
<span style="color:red;"><a href="@script@">データベースを修理する</a>か、プロバイダーに問い合わせてください。</span>',
	'info_fini' => '作業済み！',
	'info_format_image' => 'サムネイルの作成に使用できる画像フォーマット：@gd_formats@。',
	'info_format_non_defini' => '未定義のフォーマット',
	'info_grand_ecran' => '大きく表示する',
	'info_image_aide' => 'ヘルプ',
	'info_image_process_titre' => 'サムネイルの作り方',
	'info_impossible_lire_page' => '<b>エラー！</b>プロキシ経由で<code><html>@test_proxy@</html></code>ページを読むことが出来ませんでした。',
	'info_installation_systeme_publication' => '出版システムインストール…',
	'info_installer_documents' => '@upload@フォルダーにあるすべてのファイルを自動的にインストール出来ます。',
	'info_installer_ftp' => '管理者なら@upload@フォルダーに（FTPで）ファイルを置いておけば、後でここから直接そのファイルを選択できるようになります。', # MODIF
	'info_installer_images' => 'JPEG、GIF、PNGフォーマットの画像をインストール出来ます。',
	'info_installer_images_dossier' => '@upload@フォルダにインストールしたファイルをここで選択することが出来ます。',
	'info_interface_complete' => '完全なインターフェース',
	'info_interface_simple' => 'シンプルなインターフェース',
	'info_joindre_document_article' => 'この記事に添付が出来るファイルのタイプ：',
	'info_joindre_document_rubrique' => 'このセクションに添付が出来るファイルのタイプ：',
	'info_joindre_documents_article' => 'この記事に添付が出来るファイルのタイプ：',
	'info_l_article' => 'その記事',
	'info_la_breve' => 'そのニュース',
	'info_la_rubrique' => 'そのセクション',
	'info_langue_principale' => 'サイトの主な言語',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ ピクセル',
	'info_les_auteurs_1' => '@les_auteurs@で',
	'info_logo_format_interdit' => '@formats@フォーマットのロゴのみ許可します。',
	'info_logo_max_poids' => 'ロゴは、@maxi@より少ないべきです（このファイルは@actuel@）。',
	'info_mail_fournisseur' => 'watashi@isp.com',
	'info_message_2' => 'メッセージ',
	'info_message_supprime' => 'メッセージは削除された',
	'info_messages_nb' => 'メッセージ@nb@件',
	'info_messages_un' => 'メッセージ１件',
	'info_mise_en_ligne' => '公開された日付：',
	'info_modification_parametres_securite' => 'セキュリティ設定の変更する',
	'info_mois_courant' => '今月の間：',
	'info_mot_cle_ajoute' => '次のキーワードが追加された',
	'info_multi_herit' => 'デフォルト言語',
	'info_multi_langues_soulignees' => '<u>下線が引かれている言語は</u> インターフェースが翻訳されています。その言語を選んだら、公開のサイトの多くの要素（日付、形式など）は自動的に翻訳されます。下線が引かれていない言語は、サイトのメイン言語で現れます。',
	'info_multilinguisme' => '多言語',
	'info_nom_non_utilisateurs_connectes' => 'お名前は接続しているユーザーのリストに現れない。', # MODIF
	'info_nom_utilisateurs_connectes' => 'お名前は接続しているユーザーのリストに現れる。', # MODIF
	'info_nombre_en_ligne' => '今オンライン:',
	'info_non_resultat' => '「@cherche_mot@」に関する結果はありません。',
	'info_non_utilisation_messagerie' => 'サイトの内部のメッセージ交換を使用していない。',
	'info_nouveau_message' => 'メッセージが１通届いています',
	'info_nouveaux_messages' => 'メッセージが@total_messages@通届いています。',
	'info_numero_abbreviation' => '#',
	'info_obligatoire' => 'この情報は必須です。',
	'info_pense_bete' => 'メモ',
	'info_petit_ecran' => '小さく表示',
	'info_petition_close' => '請願終了',
	'info_pixels' => 'ピクセル',
	'info_plusieurs_mots_trouves' => '「@cherche_mot@」についていくつかのキーワードが見つかりました：',
	'info_portfolio_automatique' => '自動写真集：',
	'info_premier_resultat' => '［@total@件の合計より、結果の、最初の@debut_limit@件］',
	'info_premier_resultat_sur' => '[@debut_limit@ 最初の結果、トータル @total@]',
	'info_propose_1' => '［@nom_site_spip@］提出されました： @titre@',
	'info_propose_2' => '提出された記事',
	'info_propose_3' => '記事「@titre@」は公開のために提出されました。',
	'info_propose_4' => '記事をよく調べて、意見を出してください。',
	'info_propose_5' => '次のURLで、記事の付いた掲示板に移ります：',
	'info_publie_01' => '@connect_nom@は、「@titre@」を確認しました。',
	'info_publie_1' => '公開された[@nom_site_spip@]：「@titre@」です。',
	'info_publie_2' => '公開された記事',
	'info_rechercher' => 'サイト内検索',
	'info_rechercher_02' => '検索：',
	'info_remplacer_vignette' => 'デフォルトサムネイルをカスタムロゴに置き換える：',
	'info_rubriques_nb' => 'セクション@nb@つ',
	'info_rubriques_un' => 'セクション 1 つ',
	'info_sans_titre_2' => '名称未設定',
	'info_selectionner_fichier' => '@upload@フォルダのファイルを選択することが出来ます。',
	'info_selectionner_fichier_2' => 'ファイルを選択する：',
	'info_sites_nb' => 'サイト@nb@件',
	'info_sites_un' => 'サイト１件',
	'info_supprimer_vignette' => 'サムネイルを削除する',
	'info_symbole_bleu' => '<b>青色</b>は、<b>メモ</b>、つまり個人的なメッセージを表します：',
	'info_symbole_jaune' => '<b>黄色</b>は、<b>全著者向きの告知</b>を表します。つまり著者は皆読み、それに管理者は編集も出来ます。', # MODIF
	'info_symbole_vert' => '<b>緑色</b>は、サイトの<b>その他のユーザー</b>と交換されるメッセージを表します。', # MODIF
	'info_telecharger_nouveau_logo' => '新規ロゴをアップロードする：',
	'info_telecharger_ordinateur' => '当コンピュータよりアップロードする：',
	'info_tous_resultats_enregistres' => '［すべての結果は登録されます。］',
	'info_tout_afficher' => 'すべてを表示する',
	'info_travaux_texte' => 'このサイトは準備中なので、後ほど来てください。',
	'info_travaux_titre' => '開発中',
	'info_trop_resultat' => '「@cherche_mot@」に関する結果が多すぎて、 検索を改善して下さい。',
	'info_utilisation_messagerie_interne' => '内部メッセージングを使っています。',
	'info_valider_lien' => 'リンクを確認する',
	'info_verifier_image' => '、画像が正しく転送されたことを確認して下さい。',
	'info_vignette_defaut' => 'デフォルトサムネイル',
	'info_vignette_personnalisee' => 'カスタマイズサムネイル',
	'info_visite' => '訪問：',
	'info_vos_rendez_vous' => '今後の約束',
	'infos_vos_pense_bete' => 'メモ',

	// L
	'label_ajout_id_rapide' => 'クイック追加',
	'label_poids_fichier' => 'サイズ',
	'lien_afficher_icones_seuls' => 'アイコンのみ表示する',
	'lien_afficher_texte_icones' => 'アイコンとテキスト表示する',
	'lien_afficher_texte_seul' => 'テキストのみ表示する',
	'lien_liberer' => 'リリーズする',
	'lien_liberer_tous' => '全てリリーズする',
	'lien_nouvea_pense_bete' => '新規メモ',
	'lien_nouveau_message' => '新規メッセージ',
	'lien_nouvelle_annonce' => '新規アナウンス',
	'lien_petitions' => '請願書',
	'lien_popularite' => '人気度：@popularite@%',
	'lien_racine_site' => 'サイトのルート',
	'lien_reessayer' => 'やり直す',
	'lien_repondre_message' => 'このメッセージに返信する',
	'lien_supprimer' => '削除する',
	'lien_tout_afficher' => 'すべて表示',
	'lien_visite_site' => 'このサイトを訪問する',
	'lien_visites' => '@visites@訪問',
	'lien_voir_auteur' => 'この著者のページを訪れる',
	'ligne' => '一行',
	'login' => 'ログイン',
	'login_acces_prive' => '管理エリアへアクセスする',
	'login_autre_identifiant' => '他のＩＤで接続する',
	'login_cookie_accepte' => '（なるべくこのサイトのため）クッキーを許可するように、ブラウザを設定してください。',
	'login_cookie_oblige' => 'このサイト上で安全にログインするには、クッキーを受け入れる必要があります。',
	'login_deconnexion_ok' => 'ログアウト済み',
	'login_erreur_pass' => 'パスワードエラー',
	'login_espace_prive' => '管理エリア',
	'login_identifiant_inconnu' => 'ＩＤ、「@login@」は不明です。',
	'login_login' => 'ログインＩＤ：',
	'login_login2' => 'ログインＩＤ（このサイトに接続するためのＩＤ）：',
	'login_login_pass_incorrect' => '（ログインＩＤ、または、パスワードは一致しません）',
	'login_motpasseoublie' => 'パスワードを忘れましたか？',
	'login_non_securise' => '警告：このフォームは安全ではありません。 パスワードをネット上で傍受される恐れがないように、ブラウザでJavascriptを有効にしてください。',
	'login_nouvelle_tentative' => '新しい試み',
	'login_par_ici' => '登録済みなので… どうぞ…',
	'login_pass2' => 'パスワード：',
	'login_preferez_refuser' => '<b>クッキーを拒絶したければ</b>、（それほど安全でない）別の接続方法を使うことが出来ます：',
	'login_recharger' => 'このページをリフレッシュする',
	'login_rester_identifie' => 'しばらく接続したままにする', # MODIF
	'login_retour_public' => '公開サイトに戻る',
	'login_retour_site' => 'パブリックなサイトへ戻る',
	'login_retoursitepublic' => '公開サイトに戻る',
	'login_sans_cookie' => 'クッキーを拒絶して、ログインする。',
	'login_securise' => '安全ログイン',
	'login_sinscrire' => '申し込む', # MODIF
	'login_test_navigateur' => 'ブラウザテスト、接続をやり直す',
	'login_verifiez_navigateur' => '(ところが、ブラウザがパスワードを登録しなかったことを確かめて下さい。)',

	// M
	'masquer_colonne' => 'このコラムを非表示にする',
	'masquer_trad' => '翻訳を非表示にする',
	'message_nouveaux_identifiants_echec' => '新規ＩＤの制作失敗',
	'message_nouveaux_identifiants_echec_envoi' => '新しいログインＩＤ送信が出来ませんでした。',
	'message_nouveaux_identifiants_ok' => '新しいログインＩＤは@email@に送信されました。',
	'module_fichiers_langues' => '言語ファイル',

	// N
	'navigateur_pas_redirige' => 'ブラウザがリダイレクトされない場合、ここをクリックして続行してください。',
	'numero' => '番号',

	// O
	'occurence' => '生起',
	'onglet_affacer_base' => 'データベースを削除する',
	'onglet_auteur' => '著者',
	'onglet_contenu_site' => 'そのサイトの内容',
	'onglet_evolution_visite_mod' => '訪問率',
	'onglet_fonctions_avances' => '高度な機能',
	'onglet_informations_personnelles' => '個人情報',
	'onglet_interactivite' => '対話性',
	'onglet_messagerie' => 'メッセージング',
	'onglet_repartition_rubrique' => 'セクションによる配分',
	'onglet_save_restaur_base' => 'データベースバックアップ／復元する',
	'onglet_vider_cache' => 'キャッシュを空白にする',

	// P
	'pass_choix_pass' => '新しいパスワードを決めてください：',
	'pass_erreur' => 'エラー',
	'pass_erreur_acces_refuse' => '<b>エラー：</b> もはや、このサイトへのアクセスが拒否されました。',
	'pass_erreur_code_inconnu' => '<b>エラー：</b> このコードは、このサイトにアクセスするどの訪問者にも対応していません。', # MODIF
	'pass_erreur_non_enregistre' => '<b>エラー：</b> アドレス <tt>@email_oubli@</tt> は登録されていません。',
	'pass_erreur_non_valide' => '<b>エラー：</b> そのアドレス<tt>@email_oubli@</tt> は有効ではありません。',
	'pass_erreur_probleme_technique' => '<b>エラー：</b> このメールは、技術的な問題によって送信が出来ませんでした。',
	'pass_espace_prive_bla' => '管理エリアは、登録済みの訪問者に開かれています。登録されたら、記事の閲覧、記事の投稿、フォーラムへの参加が可能になります。', # MODIF
	'pass_forum_bla' => '登録された訪問者用のフォーラムに介入させてもらうように願いました。', # MODIF
	'pass_indiquez_cidessous' => '登録されたメールアドレスを下に入力してください。アクセスが再び出来るように、取り扱い説明をメールで送信します。',
	'pass_mail_passcookie' => '(自動メッセージ)サイト@nom_site_spip@(@adresse_site@)へのアクセスを取り戻すように、次のアドレスに行ってください：@sendcookie@。それで新しいパスワードを入力すると再接続ができます。', # MODIF
	'pass_mot_oublie' => 'パスワードを忘れました。',
	'pass_nouveau_enregistre' => '新しいパスワードが登録されました。',
	'pass_nouveau_pass' => '新規パスワード',
	'pass_ok' => 'オケー',
	'pass_oubli_mot' => 'パスワードは忘れています。',
	'pass_procedure_changer' => 'パスワードを変更するには、アカウントを作成した時のメールアドレスを入力してください。',
	'pass_quitter_fenetre' => 'このウィンドウを閉じる',
	'pass_rappel_login' => 'リマインダー： あなたのＩＤ (ログインＩＤ) は「@login@」です。',
	'pass_recevoir_mail' => 'パスワードをリセットするために、リンクをメールアドレスに送信されました。',
	'pass_retour_public' => '公開サイトへ戻る',
	'pass_rien_a_faire_ici' => '居るべきではありません。',
	'pass_vousinscrire' => 'サイトに登録する',
	'precedent' => '前',
	'previsualisation' => 'プレビュー',
	'previsualiser' => 'プレビューを表示する',

	// R
	'retour' => '戻る',

	// S
	'spip_conforme_dtd' => 'SPIPはこの文書がDOCTYPEに準拠していると認めます：',
	'squelette' => 'テンプレート',
	'squelette_inclus_ligne' => 'テンプレート、ラインを含む',
	'squelette_ligne' => 'テンプレート、ライン',
	'stats_visites_et_popularite' => '訪問数：@visites@； 人気率：@popularite@',
	'suivant' => '次へ',

	// T
	'taille_go' => '@taille@ Gb',
	'taille_ko' => '@taille@ kb',
	'taille_mo' => '@taille@ Mb',
	'taille_octets' => '@taille@ バイト',
	'taille_octets_bi' => '@taille@ バイト',
	'texte_actualite_site_1' => 'インターフェースに精通した時、「',
	'texte_actualite_site_2' => '完全なインターフェース',
	'texte_actualite_site_3' => '」さらに多くの特徴を利用可能にするようにクリックしてください。',
	'texte_creation_automatique_vignette' => 'プレビューサムネイルの自動制作が有効になっています。このフォームを通して画像のフォーマット@gd_formats@であれば、@size_preview@pixelsの最大サイズのサムネイルが添付されます。',
	'texte_documents_associes' => '次のファイルは記事に関連付けられていますが、挿入されていません。 公開サイトのレイアウトによって、添付ドキュメントとして表示されることもあります。',
	'texte_erreur_mise_niveau_base' => 'アップグレード中のデータベースエラー。画像 <b>@fichier@</b> をパスすることが出来なかった（記事@id_article@）。注意を払ってこの参照を残してください。また記事に画像が現れることを確認して下さい。',
	'texte_erreur_visiteur' => '権利のないＩＤを使用して管理エリアにアクセスしようとしました。',
	'texte_inc_auth_1' => 'ＩＤ<b>@auth_login@</b>でログインしていますが、このＩＤはデータベースにはもはや存在していません。',
	'texte_inc_auth_2' => 'ブラウザを再起動した後、',
	'texte_inc_auth_3' => 'もう一度接続をしてください。',
	'texte_inc_config' => 'このページの変更は、サイトの作動に大きな影響を与えます。 SPIPの操作に慣れるまで設定を変更しないことをお勧めします。<br/>基本的には、これらのページの設定変更を管理者に任せておくことを強くお勧めします。',
	'texte_inc_meta_1' => 'ファイル<code>@file@</ code>の書き込みながら、エラーが発生しました。', # MODIF
	'texte_inc_meta_2' => 'サイト管理者として、',
	'texte_inc_meta_3' => '<code>@directory@</ code>フォルダの書き込み権を確認してください。',
	'texte_statut_en_cours_redaction' => '編集中',
	'texte_statut_poubelle' => 'ゴミ箱の中',
	'texte_statut_propose_evaluation' => '確認のため提出する',
	'texte_statut_publie' => 'オンラインに公開する',
	'texte_statut_refuse' => '拒否する',
	'titre_ajouter_mot_cle' => 'キーワードを追加する：',
	'titre_cadre_raccourcis' => 'ショートカット：',
	'titre_changer_couleur_interface' => 'インターフェースの色を変える',
	'titre_image_admin_article' => 'この記事を管理することになりました。',
	'titre_image_administrateur' => '管理者', # MODIF
	'titre_image_aide' => 'この項目に関するのヘルプ',
	'titre_image_auteur_supprime' => '著者は削除された',
	'titre_image_redacteur' => 'アクセス無しの編集者',
	'titre_image_redacteur_02' => '編集者',
	'titre_image_selecteur' => 'リストを表示する',
	'titre_image_visiteur' => '訪問者',
	'titre_joindre_document' => 'ファイルを添付する',
	'titre_mots_cles' => 'キーワード',
	'titre_probleme_technique' => '警告：技術的なエラーが発生して（SQLサーバー）、サイトのこの部分へのアクセスが出来ません。 ご理解いただき、ありがとうございます。',
	'titre_publier_document' => 'このセクションにファイルを公開する',
	'titre_signatures_attente' => '署名確認中',
	'titre_signatures_confirmees' => '署名は確認された',
	'titre_statistiques' => 'サイトの統計',
	'titre_titre_document' => 'ファイルの名称：',
	'todo' => 'するべき事',
	'trad_definir_reference' => '翻訳のために参考記事「@titre@」を選んでください。',
	'trad_reference' => '（参考記事）',

	// U
	'upload_limit' => 'このファイルのサイズは大きすぎます。 <b>アップロード</b>に許可される最大サイズは@max@です。',

	// Z
	'zbug_balise_b_aval' => ': Bタグはループ内で遅すぎる',
	'zbug_balise_inexistante' => '@from@エラー：タグ#@balise@は存在していません。',
	'zbug_balise_sans_argument' => '@balise@タグのパラメーターが足りません。',
	'zbug_boucle' => 'ループ',
	'zbug_boucle_recursive_undef' => '@nom@：未定義な回帰的なループ',
	'zbug_calcul' => '制作',
	'zbug_champ_hors_boucle' => 'ループ外の@champ@フィールド',
	'zbug_champ_hors_motif' => 'フィルドは @champ@ 外部の文脈 @motif@',
	'zbug_code' => 'コード',
	'zbug_critere_inconnu' => '未知の基準@critere@',
	'zbug_critere_sur_table_sans_cle_primaire' => '{@critere@} on a table without atomic primary key',
	'zbug_distant_interdit' => '外部のデータは禁止',
	'zbug_doublon_table_sans_cle_primaire' => 'Duplicate entries on a table which does not have a simple primary key',
	'zbug_doublon_table_sans_index' => 'Duplicate entries on a table without an index',
	'zbug_erreur_boucle_double' => 'ループ@id@：二重定義',
	'zbug_erreur_boucle_fermant' => '歪んでいる@id@： 欠けている終了タグ',
	'zbug_erreur_boucle_syntaxe' => 'ループ@id@に構文エラー（BOUCLE）',
	'zbug_erreur_compilation' => 'コンパイルエラー',
	'zbug_erreur_execution_page' => 'ページの制作失敗',
	'zbug_erreur_filtre' => 'エラー：未定義のフィルター「<b>@filtre@</b>」',
	'zbug_erreur_meme_parent' => '条件{meme_parent}はループ（FORUMS）または（RUBRIQUES）だけに適用されます。',
	'zbug_erreur_squelette' => 'テンプレート内にエラーがあります。',
	'zbug_hors_compilation' => 'コンパイルされていない',
	'zbug_info_erreur_squelette' => 'サイトのエラー',
	'zbug_inversion_ordre_inexistant' => '実在しない順番の逆転',
	'zbug_pagination_sans_critere' => '基準{pagination}をもたない#PAGINATION。または再帰的ループで使用される基準。',
	'zbug_parametres_inclus_incorrects' => 'インクルードパラメータエラー：@param@',
	'zbug_profile' => '制作時間：@time@',
	'zbug_resultat' => '結果',
	'zbug_serveur_indefini' => '未定義のSQLサーバー',
	'zbug_statistiques' => '期間にソートされたSQLクエリ統計',
	'zbug_table_inconnue' => 'SQLテーブル「@table@」は見つからない',
	'zxml_connus_attributs' => '既知の属性',
	'zxml_de' => 'より',
	'zxml_inconnu_attribut' => '無知の属性',
	'zxml_inconnu_balise' => '無知のタグ',
	'zxml_inconnu_entite' => '無知の項目',
	'zxml_inconnu_id' => '無知のＩＤ',
	'zxml_mais_de' => 'より',
	'zxml_non_conforme' => '準拠していない',
	'zxml_non_fils' => 'の子ではない',
	'zxml_nonvide_balise' => '空白のないタグ',
	'zxml_obligatoire_attribut' => '必須なのに不在',
	'zxml_succession_fils_incorrecte' => '不正な子の継承',
	'zxml_survoler' => '正しいのを表すには、カーソルをその上に移動してください。',
	'zxml_valeur_attribut' => '属性の値',
	'zxml_vide_balise' => '空白のタグ',
	'zxml_vu' => '先ほど見た',
];
